@@ -121,20 +121,24 @@ typedef enum {
 	CTC_SeqDelimiter = 0x2000,
 	CTC_SeqBefore = 0x4000,
 	CTC_SeqAfter = 0x8000,
-	CTC_UserDefined0 = 0x10000,
+	CTC_UserDefined0 = 0x10000,  // class 5
 	CTC_UserDefined1 = 0x20000,
 	CTC_UserDefined2 = 0x40000,
 	CTC_UserDefined3 = 0x80000,
 	CTC_UserDefined4 = 0x100000,
 	CTC_UserDefined5 = 0x200000,
 	CTC_UserDefined6 = 0x400000,
-	CTC_UserDefined7 = 0x800000,
+	CTC_UserDefined7 = 0x800000,  // class 12
 	CTC_CapsMode = 0x1000000,
 	CTC_NumericMode = 0x2000000,
 	CTC_NumericNoContract = 0x4000000,
 	CTC_EndOfInput = 0x8000000,  // only used by pattern matcher
 	CTC_EmpMatch = 0x10000000,   // only used in TranslationTableRule->before and
 								 // TranslationTableRule->after
+	CTC_MidEndNumericMode = 0x20000000,
+	// two more bits available in a unsigned int of width 32
+	// currently used for class 13 and 14
+	CTC_Class13 = 0x40000000,
 } TranslationTableCharacterAttribute;
 
 typedef enum {
@@ -242,6 +246,7 @@ typedef enum { /* Op codes */
 	CTO_NoLetsignAfter,
 	CTO_NumberSign,
 	CTO_NumericModeChars,
+	CTO_MidEndNumericModeChars,
 	CTO_NumericNoContractChars,
 	CTO_SeqDelimiter,
 	CTO_SeqBeforeChars,
@@ -549,15 +554,15 @@ typedef enum {
 	alloc_typebuf,
 	alloc_wordBuffer,
 	alloc_emphasisBuffer,
-	alloc_transNoteBuffer,
 	alloc_destSpacing,
-	alloc_passbuf1,
-	alloc_passbuf2,
+	alloc_passbuf,
 	alloc_posMapping1,
 	alloc_posMapping2,
 	alloc_posMapping3
 } AllocBuf;
 
+#define MAXPASSBUF 3
+
 typedef enum {
 	capsRule = 0,
 	emph1Rule = 1,
@@ -584,6 +589,20 @@ typedef enum {
 	lenPhraseOffset = 8
 } EmphCodeOffset;
 
+/* Grouping the begin, end, word and symbol bits and using the type of
+ * a single bit group for representing the emphasis classes allows us
+ * to do simple bit operations. */
+
+typedef struct {
+	unsigned int begin : 16;
+	unsigned int end : 16;
+	unsigned int word : 16;
+	unsigned int symbol : 16;
+} EmphasisInfo;
+
+/* An emphasis class is a bit field that contains a single "1" */
+typedef unsigned int EmphasisClass;
+
 typedef enum { noEncoding, bigEndian, littleEndian, ascii8 } EncodingType;
 
 typedef struct {
@@ -645,7 +664,7 @@ _lou_getCharFromDots(widechar d);
  * TODO: move to utils.c
  */
 void *EXPORT_CALL
-_lou_allocMem(AllocBuf buffer, int srcmax, int destmax);
+_lou_allocMem(AllocBuf buffer, int index, int srcmax, int destmax);
 
 /**
  * Hash function for character strings
@@ -783,6 +802,12 @@ _lou_logMessage(logLevels level, const char *format, ...);
 
 extern int translation_direction;
 
+/**
+ * Return 1 if given translation mode is valid. Return 0 otherwise.
+ */
+int EXPORT_CALL
+_lou_isValidMode(int mode);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
